The Places dataset is designed following principles of human visual cognition.
Our goal is to build a core of visual knowledge that can be used to train
artificial systems for high-level visual understanding tasks, such as scene
context, object recognition, action and event prediction, and theory-of-mind
inference.

The semantic categories of Places are defined by their function: the labels
represent the entry-level of an environment. To illustrate, the dataset has
different categories of bedrooms, or streets, etc, as one does not act the same
way, and does not make the same predictions of what can happen next, in a home
bedroom, an hotel bedroom or a nursery. In total, Places contains more than 10
million images comprising 400+ unique scene categories. The dataset features
5000 to 30,000 training images per class, consistent with real-world frequencies
of occurrence. Using convolutional neural networks (CNN), Places dataset allows
learning of deep scene features for various scene recognition tasks, with the
goal to establish new state-of-the-art performances on scene-centric benchmarks.

Here we provide the Places Database and the trained CNNs for academic research
and education purposes.
